@@ -78,11 +78,16 @@ $(function() {
         $payPalMensagem.find(".msg-warning").hide();
         $payPalMensagem.toggleClass("alert-message-warning alert-message-danger");
         var $errorMessage = $("#errorMessage");
-        var $detalheErro = $("#detalheErro");
-        var $exibeDetalhesDoErro = $("#exibeDetalhesDoErro");
-        $detalheErro.text(mensagem);
-        $exibeDetalhesDoErro.show();
-        $errorMessage.text(status + ": " + mensagemDeErroPadrao);
+        if (status == 585) {
+            $errorMessage.text(mensagem);
+        }
+        else {
+            var $detalheErro = $("#detalheErro");
+            var $exibeDetalhesDoErro = $("#exibeDetalhesDoErro");
+            $detalheErro.text(mensagem);
+            $exibeDetalhesDoErro.show();
+            $errorMessage.text(status + ": " + mensagemDeErroPadrao);
+        }
         $payPalMensagem.find(".msg-danger").show();
         if (fatal) {
             $(".pagar").remove();
@@ -108,7 +113,7 @@ $(function() {
     var pedidoAguardandoPagamento = '{{ pedido.situacao_id }}' == '2' || '{{ pedido.situacao_id }}' == '3';
 
     if (window.location.search != "" && window.location.search.indexOf("failure") > -1) {
-        exibeMensagemErro(500, "Pagamento cancelado no PayPal!");
+        exibeMensagemErro(585, "Pagamento cancelado no PayPal!");
     }
     else if (window.location.search != "" && window.location.search.indexOf("success") > -1 || pedidoPago) {
         exibeMensagemSucesso("pago");
